@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMPORTFILTERPAGE_H
-#define IMPORTFILTERPAGE_H
+#pragma once
 
 #include <QWidget>
 
@@ -32,4 +31,3 @@ private:
     Ui::ImportFilterPage *const ui;
 };
 
-#endif // IMPORTFILTERPAGE_H
