@@ -49,8 +49,8 @@ void EvolutionSettings::loadAccount(const QString &filename)
     for (QDomElement e = config.firstChildElement(); !e.isNull(); e = e.nextSiblingElement()) {
         const QString tag = e.tagName();
         if (tag == QLatin1String("entry")) {
-            if (e.hasAttribute(QLatin1String("name"))) {
-                const QString attr = e.attribute(QLatin1String("name"));
+            if (e.hasAttribute(QStringLiteral("name"))) {
+                const QString attr = e.attribute(QStringLiteral("name"));
                 if (attr == QLatin1String("accounts")) {
                     readAccount(e);
                 } else if (attr == QLatin1String("signatures")) {
